import { EVMAccountAddress, EVMContractAddress, BlockchainCommonErrors, OperatorGatewayContractError, PasskeyId, P256PublicKeyComponents, P256SignatureComponents, LayerZeroEndpointId, OperatorDomain, TokenAmount } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { ContractOverrides, WrappedTransactionResponse, IOperatorGatewayContract, EOperatorGatewayRoles } from "../interfaces/index.js";
import { P256VerificationData } from "../interfaces/objects/index.js";
export declare class OperatorGatewayContract extends ERC7529Contract<OperatorGatewayContractError> implements IOperatorGatewayContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    deployWallets(usernames: string[], p256Keys: P256PublicKeyComponents[][], evmAccounts: EVMContractAddress[][] | EVMAccountAddress[][], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, OperatorGatewayContractError | BlockchainCommonErrors>;
    authorizeWalletsOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, usernames: string[], gas: bigint, nativeTokenFee: bigint, // Required fee calculated from the quote function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    authorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, gas: bigint, nativeTokenFee: bigint, // Required fee calculated from the quote function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    quoteAuthorizeWalletOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, username: string, gas: bigint): ResultAsync<TokenAmount, OperatorGatewayContractError | BlockchainCommonErrors>;
    quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, domain: OperatorDomain, gas: bigint): ResultAsync<TokenAmount, OperatorGatewayContractError | BlockchainCommonErrors>;
    addP256KeysWithP256Keys(evmAccounts: EVMContractAddress[] | EVMAccountAddress[], keyIds: PasskeyId[], p256VerificationDatas: P256VerificationData[], newP256Keys: P256PublicKeyComponents[], p256Signatures: P256SignatureComponents[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    grantRole(role: EOperatorGatewayRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    revokeRole(role: EOperatorGatewayRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    renounceRole(role: EOperatorGatewayRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    hasRole(role: EOperatorGatewayRoles, address: EVMAccountAddress): ResultAsync<boolean, OperatorGatewayContractError | BlockchainCommonErrors>;
    computeWalletAddresses(userNames: string[]): ResultAsync<EVMContractAddress[], OperatorGatewayContractError | BlockchainCommonErrors>;
    factoryAddress(): ResultAsync<EVMContractAddress, OperatorGatewayContractError | BlockchainCommonErrors>;
    domainName(): ResultAsync<string, OperatorGatewayContractError | BlockchainCommonErrors>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): OperatorGatewayContractError;
}
//# sourceMappingURL=OperatorGatewayContract.d.ts.map