var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { EVMContractAddress, SnickerdoodleFactoryContractError, InvalidParametersError, } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { injectable } from "inversify";
import { errAsync, okAsync, ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { ContractsAbis } from "../interfaces/objects/index.js";
let SnickerdoodleWalletFactoryContract = class SnickerdoodleWalletFactoryContract extends BaseContract {
    constructor(providerOrSigner, contractAddress) {
        super(providerOrSigner, contractAddress, ContractsAbis.SnickerdoodleFactoryAbi.abi);
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
    }
    setPeer(layerZeroEndpointId, SnickerdoodleWalletFactoryAddress, overrides) {
        return this.writeToContract("setPeer", [layerZeroEndpointId, SnickerdoodleWalletFactoryAddress], overrides);
    }
    peers(destinationChainEid) {
        return ResultAsync.fromPromise(this.contract.peers(destinationChainEid), (e) => {
            return this.generateError(e, "Unable to call peers()");
        }).andThen((destinationChainContractAddress) => {
            if (destinationChainContractAddress == ethers.ZeroAddress) {
                return errAsync(new InvalidParametersError("Endpoint Id provided is not set as a peer"));
            }
            return okAsync(destinationChainContractAddress);
        });
    }
    walletBeaconAddress() {
        return ResultAsync.fromPromise(this.contract.getWalletBeacon(), (e) => {
            return this.generateError(e, "Unable to call getWalletBeacon()");
        });
    }
    operatorGatewayBeaconAddress() {
        return ResultAsync.fromPromise(this.contract.getGatewayBeacon(), (e) => {
            return this.generateError(e, "Unable to call getGatewayBeacon()");
        });
    }
    deployWalletProxies(usernames, p256Keys, evmAccounts, overrides) {
        return this.writeToContract("deployWalletProxies", [usernames, p256Keys, evmAccounts], overrides);
    }
    deployWalletProxy(username, p256Keys, evmAccounts, overrides) {
        return this.writeToContract("deployWalletProxy", [username, p256Keys, evmAccounts], overrides);
    }
    updateWalletHash(newWalletHash, overrides) {
        return this.writeToContract("updateWalletHash", [newWalletHash], overrides);
    }
    deployOperatorGatewayProxy(domain, adminAccounts, operatorAccounts, overrides) {
        return this.writeToContract("deployOperatorGatewayProxy", [domain, adminAccounts, operatorAccounts], overrides);
    }
    authorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, domain, gas, nativeTokenFee, // Required fee calculated from the quoteAuthorizeOperatorGatewayOnDestinationChain function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides) {
        // If there are no overrides provided, create an empty object
        const overridesWithFee = overrides ? overrides : {};
        // include the fee in the overrides object
        overridesWithFee.value = nativeTokenFee;
        return this.writeToContract("authorizeGatewayOnDestinationChain", [destinationLayerZeroEndpointId, domain, gas], overrides);
    }
    quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, domain, gas) {
        return ResultAsync.fromPromise(this.contract.quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, domain, gas), (e) => {
            return this.generateError(e, "Unable to call quoteAuthorizeOperatorGatewayOnDestinationChain()");
        }).map((quotedFee) => {
            // The quoted fee is returned as fee in [native token, layer zero token]
            // We only need the native token fee amount
            return quotedFee[0];
        });
    }
    computeProxyAddress(salt, // The salt used to create the proxy address
    beaconAddress) {
        return ResultAsync.fromPromise(this.contract.computeProxyAddress(salt, beaconAddress), (e) => {
            return this.generateError(e, "Unable to call computeProxyAddress()");
        });
    }
    computeWalletAddress(username) {
        return ResultAsync.fromPromise(this.contract.computeWalletAddress(username), (e) => {
            return this.generateError(e, "Unable to call computeWalletAddress()");
        });
    }
    isSourceChain() {
        return ResultAsync.fromPromise(this.contract.getIsSourceChain(), (e) => {
            return this.generateError(e, "Unable to call getIsSourceChain()");
        });
    }
    getOperatorDomainName(operatorGatewayAddress) {
        return ResultAsync.fromPromise(this.contract.getOperatorDomain(operatorGatewayAddress), (e) => {
            return this.generateError(e, "Unable to call getOperatorDomain()");
        });
    }
    getWalletHash(walletAddress) {
        return ResultAsync.fromPromise(this.contract.getWalletHash(walletAddress), (e) => {
            return this.generateError(e, "Unable to call getWalletHash()");
        });
    }
    getOperatorHash(operatorGatewayAddress) {
        return ResultAsync.fromPromise(this.contract.getOperatorHash(operatorGatewayAddress), (e) => {
            return this.generateError(e, "Unable to call getOperatorHash()");
        });
    }
    generateContractSpecificError(msg, e, transaction) {
        return new SnickerdoodleFactoryContractError(msg, e, transaction);
    }
};
SnickerdoodleWalletFactoryContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String])
], SnickerdoodleWalletFactoryContract);
export { SnickerdoodleWalletFactoryContract };
//# sourceMappingURL=SnickerdoodleFactoryContract.js.map