import { EVMAccountAddress, EVMContractAddress, BlockchainCommonErrors, SnickerdoodleWalletContractError, WebauthnCredentialId, P256PublicKeyComponents, P256SignatureComponents, InvalidParametersError, ClientDataJSONComponents, AuthenticatorData } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { Result, ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ContractOverrides, WrappedTransactionResponse, ISnickerdoodleWalletContract } from "../interfaces/index.js";
export declare class SnickerdoodleWalletContract extends BaseContract<SnickerdoodleWalletContractError> implements ISnickerdoodleWalletContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    factoryAddress(): ResultAsync<EVMContractAddress, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    operatorAddress(): ResultAsync<EVMContractAddress, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    addP256KeyWithP256Key(keyId: WebauthnCredentialId, authenticatorData: AuthenticatorData, clientDataJSON: ClientDataJSONComponents, newP256Key: P256PublicKeyComponents, p256Signature: P256SignatureComponents, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    static generateAddP256KeyWithP256KeyChallenge(newKeyId: WebauthnCredentialId, newP256PublicKey: P256PublicKeyComponents): Result<Uint8Array, InvalidParametersError>;
    addEVMAddressWithP256Key(keyId: WebauthnCredentialId, authenticatorData: AuthenticatorData, clientDataJSON: ClientDataJSONComponents, evmAccount: EVMAccountAddress | EVMContractAddress, p256Signature: P256SignatureComponents, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    static generateAddEVMAddressWithP256KeyChallenge(evmAccountAddress: EVMAccountAddress): Result<Uint8Array, InvalidParametersError>;
    addEVMAccountWithEVMAccount(evmAccount: EVMAccountAddress | EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    removeEVMAccountWithEVMAccount(evmAccount: EVMAccountAddress | EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    withdrawLocalERC20Asset(tokenAddress: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    withdrawNativeAsset(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleWalletContractError>;
    name(): ResultAsync<string, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    p256KeyHashes(): ResultAsync<string[], SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    p256Key(keyHash: string): ResultAsync<{
        keyId: WebauthnCredentialId;
        p256PublicKeyComponents: P256PublicKeyComponents;
    }, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    evmAccounts(): ResultAsync<EVMAccountAddress[], SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    evmAccountIndex(address: EVMAccountAddress | EVMContractAddress): ResultAsync<number, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    hashUsed(hash: string): ResultAsync<boolean, SnickerdoodleWalletContractError | BlockchainCommonErrors>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): SnickerdoodleWalletContractError;
}
//# sourceMappingURL=SnickerdoodleWalletContract.d.ts.map