// Source: https://optimistic.etherscan.io/address/0x00000000fc25870c6ed6b6c7e41fb078b7656f69#code
// based on https://docs.farcaster.xyz/reference/contracts/deployments#abis
export default {
    abi: [
        {
            inputs: [
                { internalType: "address", name: "_idRegistry", type: "address" },
                { internalType: "address", name: "_storageRegistry", type: "address" },
                { internalType: "address", name: "_initialOwner", type: "address" },
            ],
            stateMutability: "nonpayable",
            type: "constructor",
        },
        { inputs: [], name: "CallFailed", type: "error" },
        {
            inputs: [
                { internalType: "address", name: "account", type: "address" },
                { internalType: "uint256", name: "currentNonce", type: "uint256" },
            ],
            name: "InvalidAccountNonce",
            type: "error",
        },
        { inputs: [], name: "InvalidShortString", type: "error" },
        { inputs: [], name: "InvalidSignature", type: "error" },
        { inputs: [], name: "OnlyGuardian", type: "error" },
        { inputs: [], name: "SignatureExpired", type: "error" },
        {
            inputs: [{ internalType: "string", name: "str", type: "string" }],
            name: "StringTooLong",
            type: "error",
        },
        { inputs: [], name: "Unauthorized", type: "error" },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: true,
                    internalType: "address",
                    name: "guardian",
                    type: "address",
                },
            ],
            name: "Add",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [],
            name: "EIP712DomainChanged",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: true,
                    internalType: "address",
                    name: "previousOwner",
                    type: "address",
                },
                {
                    indexed: true,
                    internalType: "address",
                    name: "newOwner",
                    type: "address",
                },
            ],
            name: "OwnershipTransferStarted",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: true,
                    internalType: "address",
                    name: "previousOwner",
                    type: "address",
                },
                {
                    indexed: true,
                    internalType: "address",
                    name: "newOwner",
                    type: "address",
                },
            ],
            name: "OwnershipTransferred",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: false,
                    internalType: "address",
                    name: "account",
                    type: "address",
                },
            ],
            name: "Paused",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: true,
                    internalType: "address",
                    name: "guardian",
                    type: "address",
                },
            ],
            name: "Remove",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: false,
                    internalType: "address",
                    name: "oldStorageRegistry",
                    type: "address",
                },
                {
                    indexed: false,
                    internalType: "address",
                    name: "newStorageRegistry",
                    type: "address",
                },
            ],
            name: "SetStorageRegistry",
            type: "event",
        },
        {
            anonymous: false,
            inputs: [
                {
                    indexed: false,
                    internalType: "address",
                    name: "account",
                    type: "address",
                },
            ],
            name: "Unpaused",
            type: "event",
        },
        {
            inputs: [],
            name: "REGISTER_TYPEHASH",
            outputs: [{ internalType: "bytes32", name: "", type: "bytes32" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "VERSION",
            outputs: [{ internalType: "string", name: "", type: "string" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "acceptOwnership",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "guardian", type: "address" }],
            name: "addGuardian",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "domainSeparatorV4",
            outputs: [{ internalType: "bytes32", name: "", type: "bytes32" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "eip712Domain",
            outputs: [
                { internalType: "bytes1", name: "fields", type: "bytes1" },
                { internalType: "string", name: "name", type: "string" },
                { internalType: "string", name: "version", type: "string" },
                { internalType: "uint256", name: "chainId", type: "uint256" },
                { internalType: "address", name: "verifyingContract", type: "address" },
                { internalType: "bytes32", name: "salt", type: "bytes32" },
                { internalType: "uint256[]", name: "extensions", type: "uint256[]" },
            ],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "guardian", type: "address" }],
            name: "guardians",
            outputs: [{ internalType: "bool", name: "isGuardian", type: "bool" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [
                { internalType: "bytes32", name: "structHash", type: "bytes32" },
            ],
            name: "hashTypedDataV4",
            outputs: [{ internalType: "bytes32", name: "", type: "bytes32" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "idRegistry",
            outputs: [
                { internalType: "contract IIdRegistry", name: "", type: "address" },
            ],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "owner", type: "address" }],
            name: "nonces",
            outputs: [{ internalType: "uint256", name: "", type: "uint256" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "owner",
            outputs: [{ internalType: "address", name: "", type: "address" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "pause",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "paused",
            outputs: [{ internalType: "bool", name: "", type: "bool" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "pendingOwner",
            outputs: [{ internalType: "address", name: "", type: "address" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [
                { internalType: "uint256", name: "extraStorage", type: "uint256" },
            ],
            name: "price",
            outputs: [{ internalType: "uint256", name: "", type: "uint256" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [],
            name: "price",
            outputs: [{ internalType: "uint256", name: "", type: "uint256" }],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "recovery", type: "address" }],
            name: "register",
            outputs: [
                { internalType: "uint256", name: "", type: "uint256" },
                { internalType: "uint256", name: "", type: "uint256" },
            ],
            stateMutability: "payable",
            type: "function",
        },
        {
            inputs: [
                { internalType: "address", name: "recovery", type: "address" },
                { internalType: "uint256", name: "extraStorage", type: "uint256" },
            ],
            name: "register",
            outputs: [
                { internalType: "uint256", name: "fid", type: "uint256" },
                { internalType: "uint256", name: "overpayment", type: "uint256" },
            ],
            stateMutability: "payable",
            type: "function",
        },
        {
            inputs: [
                { internalType: "address", name: "to", type: "address" },
                { internalType: "address", name: "recovery", type: "address" },
                { internalType: "uint256", name: "deadline", type: "uint256" },
                { internalType: "bytes", name: "sig", type: "bytes" },
            ],
            name: "registerFor",
            outputs: [
                { internalType: "uint256", name: "", type: "uint256" },
                { internalType: "uint256", name: "", type: "uint256" },
            ],
            stateMutability: "payable",
            type: "function",
        },
        {
            inputs: [
                { internalType: "address", name: "to", type: "address" },
                { internalType: "address", name: "recovery", type: "address" },
                { internalType: "uint256", name: "deadline", type: "uint256" },
                { internalType: "bytes", name: "sig", type: "bytes" },
                { internalType: "uint256", name: "extraStorage", type: "uint256" },
            ],
            name: "registerFor",
            outputs: [
                { internalType: "uint256", name: "fid", type: "uint256" },
                { internalType: "uint256", name: "overpayment", type: "uint256" },
            ],
            stateMutability: "payable",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "guardian", type: "address" }],
            name: "removeGuardian",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "renounceOwnership",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [
                { internalType: "address", name: "_storageRegistry", type: "address" },
            ],
            name: "setStorageRegistry",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "storageRegistry",
            outputs: [
                {
                    internalType: "contract IStorageRegistry",
                    name: "",
                    type: "address",
                },
            ],
            stateMutability: "view",
            type: "function",
        },
        {
            inputs: [{ internalType: "address", name: "newOwner", type: "address" }],
            name: "transferOwnership",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "unpause",
            outputs: [],
            stateMutability: "nonpayable",
            type: "function",
        },
        {
            inputs: [],
            name: "useNonce",
            outputs: [{ internalType: "uint256", name: "", type: "uint256" }],
            stateMutability: "nonpayable",
            type: "function",
        },
        { stateMutability: "payable", type: "receive" },
    ],
};
//# sourceMappingURL=FarcasterIdGatewayAbi.js.map